# Generated by Django 5.2.4 on 2025-11-27 03:01

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_issue_capture", "0002_remove_chat_feature"),
    ]

    operations = [
        migrations.AlterField(
            model_name="issuecapturesettings",
            name="llm_model",
            field=models.CharField(
                default="gpt-4o-mini",
                help_text="LiteLLM model identifier. Format: provider/model-name. Examples: gpt-4o-mini (OpenAI), anthropic/claude-3-5-sonnet-20241022, ollama_chat/llama3",
                max_length=100,
            ),
        ),
        migrations.AlterField(
            model_name="issuecapturesettings",
            name="llm_temperature",
            field=models.FloatField(
                blank=True,
                default=None,
                help_text="Leave blank to use provider's default. If set: 0.0 = deterministic, higher = more creative. Note: Anthropic range is 0-1, OpenAI range is 0-2.",
                null=True,
            ),
        ),
    ]
