# Generated by Django 5.2.4 on 2025-11-27 03:16

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_issue_capture", "0003_alter_issuecapturesettings_llm_model_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="issuecapturesettings",
            old_name="llm_enabled",
            new_name="show_ai_interface",
        ),
        migrations.AlterField(
            model_name="issuecapturesettings",
            name="show_ai_interface",
            field=models.BooleanField(default=True, help_text="Show AI Generate tab in issue creation interface"),
        ),
    ]
