<!-- Empty content closes the modal (replaces #issue-capture-container) -->

<!-- OOB swap injects toast into the toast container -->
<div id="issue-toast-container" hx-swap-oob="innerHTML">
    <div class="toast" role="alert" data-bs-autohide="true" data-bs-delay="5000">
        <div class="toast-header bg-success text-white">
            <i class="bi bi-check-circle-fill me-2"></i>
            <strong class="me-auto">Issue Created!</strong>
            <button type="button" class="btn-close btn-close-white" data-bs-dismiss="toast"></button>
        </div>
        <div class="toast-body">
            {% if request.user.is_staff %}
                Issue <a href="{{ issue.get_absolute_url }}">#{{ issue.short_uuid }}</a> has been successfully created.
            {% else %}
                Your issue has been successfully submitted. Thank you!
            {% endif %}
        </div>
    </div>
</div>
